==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/FSGroupStrategyOptionsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class FSGroupStrategyOptionsBuilder extends io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluentImpl<io.fabric8.openshift.api.model.FSGroupStrategyOptionsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.FSGroupStrategyOptions,io.fabric8.openshift.api.model.FSGroupStrategyOptionsBuilder>{
  public FSGroupStrategyOptionsBuilder() {
    this(false);
  }
  public FSGroupStrategyOptionsBuilder(java.lang.Boolean validationEnabled) {
    this(new FSGroupStrategyOptions(), validationEnabled);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new FSGroupStrategyOptions(), validationEnabled);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent,io.fabric8.openshift.api.model.FSGroupStrategyOptions instance) {
    this(fluent, instance, false);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent,io.fabric8.openshift.api.model.FSGroupStrategyOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRanges(instance.getRanges()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptions instance) {
    this(instance,false);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRanges(instance.getRanges()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.FSGroupStrategyOptions build() {
    FSGroupStrategyOptions buildable = new FSGroupStrategyOptions(fluent.getRanges(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FSGroupStrategyOptionsBuilder that = (FSGroupStrategyOptionsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.1-sources.jar: io/fabric8/openshift/api/model/FSGroupStrategyOptionsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class FSGroupStrategyOptionsBuilder extends io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluentImpl<io.fabric8.openshift.api.model.FSGroupStrategyOptionsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.FSGroupStrategyOptions,io.fabric8.openshift.api.model.FSGroupStrategyOptionsBuilder>{
  public FSGroupStrategyOptionsBuilder() {
    this(false);
  }
  public FSGroupStrategyOptionsBuilder(java.lang.Boolean validationEnabled) {
    this(new FSGroupStrategyOptions(), validationEnabled);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent) {
    this(fluent, false);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new FSGroupStrategyOptions(), validationEnabled);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent,io.fabric8.openshift.api.model.FSGroupStrategyOptions instance) {
    this(fluent, instance, false);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent,io.fabric8.openshift.api.model.FSGroupStrategyOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withRanges(instance.getRanges()); 
    fluent.withType(instance.getType()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptions instance) {
    this(instance,false);
  }
  public FSGroupStrategyOptionsBuilder(io.fabric8.openshift.api.model.FSGroupStrategyOptions instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withRanges(instance.getRanges()); 
    this.withType(instance.getType()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.FSGroupStrategyOptionsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.FSGroupStrategyOptions build() {
    FSGroupStrategyOptions buildable = new FSGroupStrategyOptions(fluent.getRanges(),fluent.getType());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FSGroupStrategyOptionsBuilder that = (FSGroupStrategyOptionsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
